diff --git a/arduino_32U4.h b/arduino_32U4.h
index 0634f4d..d19b600 100644
--- a/arduino_32U4.h
+++ b/arduino_32U4.h
@@ -37,14 +37,17 @@
 #define SDA          DIO6
 
 // timers and PWM
+// The 32U4 PWMs are fairly restricted.  If you avoid timer 1 for the clock, 
+// two pairs of the PWMs are complements of each other. DIO11&DIO12 on ~OC4D&OC4D, and DIO14&DIO15 on ~OC4B&OC4B
 #define TIMER4_IS_10_BIT
-#define OC0A         DIO4
-#define OC0B         DIO5
-#define OC3A         DIO9
-#define OC4A         D1O10
-#define OC4D         DIO12
-#define OC1A         DIO14
-#define OC1B         DIO16
+#define OC0A         DIO4  // PB7
+#define OC0B         DIO5  // PD0
+#define OC3A         DIO9  // PC6 10 bit timer available on OC4A, but then it is the inverse of pin 10
+#define OC4A         D1O10 // PC7
+//#define OC4D         DIO11 // PD6 AIO10 inverse of PWM on pin DIO12  
+#define OC4D         DIO12 // PD7 AIO9
+//#define OC4B         DIO14  // PB5 AIO5 isn't independent of DIO15
+#define OC4B         DIO15 // PB6 AIO6
 
 
 // change for your board
@@ -114,23 +117,25 @@ pins
 #define DIO8_PWM     NULL
 #define DIO8_DDR     DDRD
 
+
 #define DIO9_PIN     PINC6
 #define DIO9_RPORT   PINC
 #define DIO9_WPORT   PORTC
-#define DIO9_PWM     &OCR3A
+#define DIO9_PWM     &OCR3AL // pin 9/c6 OC3A/-OC4A are a 16 and 8/10 bit timer. Inverse of pin 10 OCR4A PWM
+                            // &OCR3A would be an independent counter, 
 #define DIO9_DDR     DDRC
 
 #define DIO10_PIN    PINC7
 #define DIO10_RPORT  PINC
 #define DIO10_WPORT  PORTC
-#define DIO10_PWM    &OCR4A
+#define DIO10_PWM    &OCR4A  // inverse.  pin 10/c7 is on a 8/10 bit timer 4 and share the same register as inverses
 #define DIO10_DDR    DDRC
 
 #define DIO11_PIN    PIND6
 #define DIO11_RPORT  PIND
 #define DIO11_WPORT  PORTD
-// note that this PWM is true on not-OCR4D
-#define DIO11_PWM    &OCR4D
+// note that this PWM is true on not-OCR4D  // Complimentary signal of DIO12 PWM
+#define DIO11_PWM    NULL   // could be &OCR4D, but isn't independent of DIO12
 #define DIO11_DDR    DDRD
 
 #define DIO12_PIN    PIND7
@@ -148,13 +153,13 @@ pins
 #define DIO14_PIN    PINB5
 #define DIO14_RPORT  PINB
 #define DIO14_WPORT  PORTB
-#define DIO14_PWM    &OCR4B
+#define DIO14_PWM    NULL  // &OCR4BL is inverse complimentary signal of DIO15_PWM
 #define DIO14_DDR    DDRB
 
 #define DIO15_PIN    PINB6
 #define DIO15_RPORT  PINB
 #define DIO15_WPORT  PORTB
-#define DIO15_PWM    &OCR4B
+#define DIO15_PWM    &OCR4B  // complimentary signal of DIO14_PWM
 #define DIO15_DDR    DDRB
 
 #define DIO16_PIN    PINF7
@@ -288,7 +293,7 @@ pins
 #define AIO10_WPORT  PORTD
 #define AIO10_PWM    NULL
 #define AIO10_DDR    DDRD
-#define AIO10_ADC    10
+#define AIO10_ADC     10
 
 #define AIO11_PIN    PIND4
 #define AIO11_RPORT  PIND
diff --git a/heater.c b/heater.c
index 62d5981..0ebe450 100644
--- a/heater.c
+++ b/heater.c
@@ -136,13 +140,16 @@ void heater_init() {
 						TCCR4A |= MASK(COM4C1);
 						break;
 					#else
-					// 10 bit timer
+					// 10 bit timer, e.g. atmega32U4
 					case (uint16_t) &OCR4A:
 						TCCR4A |= MASK(COM4A1);
 						break;
 					case (uint16_t) &OCR4B:
 						TCCR4A |= MASK(COM4B1);
 						break;
+					case (uint16_t) &OCR4D:
+						TCCR4C |= MASK(COM4D1);
+						break;
 					#endif
 				#endif
 				#ifdef	TCCR5A
@@ -268,7 +275,7 @@ void heater_tick(heater_t h, temp_type_t type, uint16_t current_temp, uint16_t t
 		if (DEBUG_PID && (debug_flags & DEBUG_PID))
 			sersendf_P(PSTR("T{E:%d, P:%d * %ld = %ld / I:%d * %ld = %ld / D:%d * %ld = %ld # O: %ld = %u}\n"), t_error, heater_p, heaters_pid[h].p_factor, (int32_t) heater_p * heaters_pid[h].p_factor / PID_SCALE, heaters_runtime[h].heater_i, heaters_pid[h].i_factor, (int32_t) heaters_runtime[h].heater_i * heaters_pid[h].i_factor / PID_SCALE, heater_d, heaters_pid[h].d_factor, (int32_t) heater_d * heaters_pid[h].d_factor / PID_SCALE, pid_output_intermed, pid_output);
 		#endif
-	#else
+        #else //BANG_BANG
 		if (current_temp >= target_temp)
 			pid_output = BANG_BANG_OFF;
 		else
diff --git a/mendel.c b/mendel.c
index 3e66890..c62ec9b 100644
--- a/mendel.c
+++ b/mendel.c
@@ -225,8 +225,12 @@ void io_init(void) {
 	#ifdef	TCCR4A
 		#ifdef TIMER4_IS_10_BIT
 			// ATmega16/32U4 fourth timer is a 10 special bit timer
-			TCCR4D = MASK(WGM40);
-			TCCR4B = MASK(CS40);
+         		TCCR4A = MASK(PWM4A) |MASK(PWM4B) ; // enable A and B
+			TCCR4C = MASK(PWM4D); // and D
+			TCCR4D = MASK(WGM40); // Phase correct
+			TCCR4B = MASK(CS40);  // no prescaler
+                        TC4H   = 0;  // clear high bits
+                        OCR4C  = 0xff; // 8 bit max count at top before reset
 		#else
 			TCCR4A = MASK(WGM40);
 			TCCR4B = MASK(WGM42) | MASK(CS40);
@@ -234,6 +238,9 @@ void io_init(void) {
 		TIMSK4 = 0;
 		OCR4A = 0;
 		OCR4B = 0;
+                #ifdef __AVR_ATmega32U4__  
+		OCR4D = 0;   //  For ATmega32U/4 port PD7/DIO12 PWM
+		#endif
 	#endif
 
 	#ifdef	TCCR5A
